@@ -18,11 +18,11 @@ import getpass
 import datetime
 import distro
 import time
-from .logger import log, flush
+from .logger import log
 import aiofiles
 import asyncio
 from rich.live import Live
-
+import toml
 
 class Reload:
     """Blank object used to reload the instance."""
@@ -53,10 +53,16 @@ class Client:
         self._actual_functions: Dict[str, Callable] = {
             "resp": self.get_command_response
         }
+
+        get = lambda x: os.path.join(cm_dir, x)
+
         self._variables: Dict[str, str] = {
             "path": str(self._path),
             "config": self.config_path,
-            "cmdir": self.cm_dir,
+            "cmdir": cm_dir,
+            "logs": get('logs'),
+            "commands": get('commands'),
+            "middleware": get('middleware')
         }
         self._aliases: Dict[str, str] = {}
         self._vals: Dict[Any, Any] = {}
@@ -65,13 +71,33 @@ class Client:
             self._aliases[i] = await self.load_variables(
                 self._config.aliases[i])
 
-        colorama.init(convert=os.name == "nt")  # enables ascii stuff
+        colorama.init(convert = os.name == "nt") # enables ansi stuff
         console.clear(), title("Control Manual")
 
         self._connected = False
         self._thread_running = True
         rethread.thread(threaded, self)
         self._history: List[str] = []
+
+        lockfile = os.path.join(cm_dir, 'config-lock.toml')
+
+        with open(lockfile) as f: # cant use aiofiles here since toml doesnt support it
+            load = toml.load(f)
+        
+        environ = load["environment"]
+        
+        if not environ["installed"]:
+            with console.console.status("Installing...", spinner="shark"):
+                resp = await api.download_package('builtin')
+                
+            if not resp:
+                print('Failed to install builtins!')
+            else:
+                environ["installed"] = True
+
+                with open(lockfile, 'w') as f:
+                    toml.dump(load, f)
+
         with console.console.status("Loading commands...", spinner="material"):
             await self.reload()
 
@@ -172,7 +198,7 @@ class Client:
     @property
     def commands(
         self,
-    ) -> Dict[str, Union[str, Dict[str, Union[str, Union[Callable, dict]]]]]:
+    ) -> Dict[str, Dict[str, Union[str, Callable]]]:
         """Dictionary representation of commands."""
         return self._commands
 
@@ -318,6 +344,10 @@ Uptime: [important]{int(uptime) // 60} minutes[/important]
             command: str = console.take_input(inp, self.commands, self.aliases)
 
             console.clear_panel("exceptions")
+            try:
+                console.screen["tmp"].visible = False
+            except:
+                pass
             command = command.replace(r"\n", "\n")
 
             await self.run_command(command)
@@ -376,7 +406,13 @@ Uptime: [important]{int(uptime) // 60} minutes[/important]
                 else:
                     break
 
-            args, kwargs, flags = await parse(raw_args)
+            p = await parse(raw_args)
+
+            if not p:
+                return error('Invalid argument string.')
+
+            args, kwargs, flags = p
+
             cmd: str = cmd.lower()
 
             crfn: Optional[str] = self.current_function
@@ -456,7 +492,7 @@ Uptime: [important]{int(uptime) // 60} minutes[/important]
                     await log("running command")
                     console.clear()
 
-                    if current_command["live"]: # type: ignore
+                    if current_command["live"]:
                         with Live(console.get_terminal()):
                             await runner(raw_args, args, kwargs, flags, self)
                     else:
